export DH_ALWAYS_EXCLUDE=CVS
export LC_COLLATE=C
export DEB_BUILD_ARCH ?= $(shell dpkg-architecture -qDEB_BUILD_ARCH)

# current package version
DEBIAN_VERSION=$(strip $(shell \
		head -n 1 debian/changelog | cut -f 2 -d ' ' | tr -d '()'))

# current upstream version (remove any epoch and Debian release number)
UPSTREAM_VERSION=$(shell echo $(DEBIAN_VERSION) | \
		 sed -e 's/-[^-]*$$//' -e 's/^[^:]*://')

LOCAL_DEFINES = -DCERNLIB_DEBIAN -DDEBIAN_VERSION=\"$(DEBIAN_VERSION)\"

# location of patches
PATCHDIR = debian/patches
# location of non-Debian-specific add-ons
ADDONDIR = debian/add-ons

# output a helpful usage message if this target is invoked
help:
	@[ -e debian/README.source ] && cat debian/README.source || \
		echo "Sorry, no help for debian/rules available."

# This target downloads source code from the Cernlib web site to the
# directory "upstream".  Requires "wget" package.
get-orig-source:
	set -e ; \
	mkdir -p upstream ; \
	cd upstream ; \
	for file in $(MY_MODULES) ; \
	do \
		wget --continue http://wwwinfo.cern.ch/asd/cernlib/download/2005_source/tar/src_$${file}.tar.gz ; \
	done

# This target recreates the source code tar.gz files, having deleted those
# files with GPL-incompatible copyrights as listed in debian/deadpool.txt
remove-deadpool:
	chmod a+x $(ADDONDIR)/bin/remove-deadpool
	$(ADDONDIR)/bin/remove-deadpool
	$(MAKE) -f debian/rules debian/copyright

# This target creates an orig.tar.gz file in the directory ".."
# Don't do this if you already have an orig.tar.gz for this source version, 
# as the md5sums will not match!
orig.tar.gz: ../$(MY_NAME)_$(UPSTREAM_VERSION).orig.tar.gz

../$(MY_NAME)_$(UPSTREAM_VERSION).orig.tar.gz:
	$(MAKE) -f debian/rules clean remove-deadpool
	mkdir ../$(MY_NAME)-$(UPSTREAM_VERSION).orig
	cp -a upstream ../$(MY_NAME)-$(UPSTREAM_VERSION).orig
	cd .. && tar czf $(MY_NAME)_$(UPSTREAM_VERSION).orig.tar.gz \
		$(MY_NAME)-$(UPSTREAM_VERSION).orig
	rm -rf ../$(MY_NAME)-$(UPSTREAM_VERSION).orig

# Do not depend on build-indep so that buildd's don't needlessly run
# build-indep target.
build: build-arch

Makefile: $(ADDONDIR)/Makefile
	cp -f $(ADDONDIR)/Makefile .

unpack: Makefile
	dh_testdir
	$(MAKE) prefix=/usr mandir=/usr/share/man sysconfdir=/etc \
		LOCAL_DEFINES='$(LOCAL_DEFINES)' stampdir/configure-stamp

# Dpatch stuff
DPATCH_STAMPFN = stampdir/patch-stamp
${DPATCH_STAMPFN}: unpack
include /usr/share/dpatch/dpatch.make

patched: patch
build-arch: patch
	dh_testdir
	# force use of system cfortran.h since we Build-Depend upon it
	-mv -f src/include/cfortran/cfortran.h \
		src/include/cfortran/cfortran.h.disabled
	$(MAKE) prefix=/usr mandir=/usr/share/man sysconfdir=/etc \
		LOCAL_DEFINES='$(LOCAL_DEFINES)' cernlib-arch
ifeq (,$(findstring keepbuild,$(DEB_BUILD_OPTIONS)))
	# delete build tree to save disk space (only if both builds are done)
	if [ -e stampdir/cernlib-indep-stamp ] ; then rm -rf build ; fi
endif

build-indep: patch
	dh_testdir
	$(MAKE) prefix=/usr mandir=/usr/share/man sysconfdir=/etc \
		LOCAL_DEFINES='$(LOCAL_DEFINES)' cernlib-indep
ifeq (,$(findstring keepbuild,$(DEB_BUILD_OPTIONS)))
	# delete build tree to save disk space (only if both builds are done)
	if [ -e stampdir/cernlib-arch-stamp ] ; then rm -rf build ; fi
endif

unpatch-clean:
	# Move this back so reverse patch doesn't fail
	-mv -f src/include/cfortran/cfortran.h.disabled \
		src/include/cfortran/cfortran.h

unpatch: unpatch-clean

clean: Makefile
	dh_testdir
	dh_testroot
	@if ! $(MAKE) -f debian/rules unpatch ; then \
		echo ; \
		echo "The last patch listed above failed to de-apply.  To" ; \
		echo "inspect the situation, hit Ctrl+C within 10 seconds." ; \
		for i in `seq 10 -1 1` ; do \
			echo -n "$$i " ; sleep 1 ; \
		done ; \
		echo ; \
		rm -rf debian/patched debian/patches/00list ; \
	fi
	$(MAKE) prefix=/usr clean
	rm -f Makefile $(ADDONDIR)/bin/kuipc
	rm -rf upstream/200?
	rm -rf debian/tmp/
	-find . -name higz_windows.dat -o -name last.kumac \
		-o -name last.kumacold -o -name paw.metafile | xargs rm -f
	-rm -rf lib*.txt libdeps/ bindeps/ # clean up output of makedeplist
	dh_clean
	# Remove symlinks to debhelper snippets:
	find debian -maxdepth 1 -type l | xargs rm -f
	# Regenerate debian/control and debian/copyright:
	rm -f debian/control && $(MAKE) -f debian/rules debian/control
	rm -f debian/copyright && $(MAKE) -f debian/rules debian/copyright
	# Regenerate debian/patches/00list:
	cd $(PATCHDIR) && ls -1 *.dpatch > 00list
	# Make sure scripts are executable (but not READMEs):
	-chmod a+x $(ADDONDIR)/bin/[a-z]*
	-chmod a+x $(ADDONDIR)/scripts/[a-z]*

debian/control:
	# n.b. all control snippets in arch-specific subdirs must be
	# named "*.arch.control" so they can be cleaned up properly
	cd debian/control.d ; \
	for dir in $(DEB_BUILD_ARCH) no-* ; do \
		if [ -d $$dir ] && [ ! $$dir = no-"$(DEB_BUILD_ARCH)" ] ; \
		then cp -p $$dir/* . ; \
		fi ; \
	done ; \
	cat 0base.control [a-z]*.control > ../control ; \
	rm -f *.arch.control

debian/copyright: debian/copyright.in debian/deadpool.txt
	# Stick a list of removed files at the end of debian/copyright
	grep -v DEADPOOL_LIST_GOES_HERE debian/copyright.in > $@
	sed -e 's/#.*//g' -e '/^[[:space:]]*$$/d' debian/deadpool.txt | \
		sort | uniq >> $@

install-common:
	# Set up debhelper links.
	cd debian ; for file in debhelper/* ; do \
		ln -sf $$file ; \
	done
	dh_testdir
	dh_testroot
	dh_clean -k

# target to install arch-dependent files
install-arch: install-common build-arch
	dh_installdirs -a
	mkdir -p debian/tmp/etc/logrotate.d
	$(MAKE) DESTDIR="$(CURDIR)/debian/tmp" prefix=/usr \
		mandir=/usr/share/man sysconfdir=/etc install-arch
	debian/rules install-arch-local

install-arch-local:

# target to install arch-independent files
install-indep: install-common build-indep
	dh_installdirs -i
	$(MAKE) DESTDIR="$(CURDIR)/debian/tmp" prefix=/usr \
		mandir=/usr/share/man sysconfdir=/etc install-indep
	debian/rules install-indep-local

install-indep-local:

install: install-indep install-arch
binary-arch: install-arch
binary-indep: install-indep
binary: binary-indep binary-arch

.PHONY: help get-orig-source remove-deadpool build build-indep build-arch \
	clean debian/control install install-common install-indep install-arch\
	install-indep-local install-arch-local \
	binary binary-indep binary-arch unpack patch unpatch setup orig.tar.gz\
	unpatch-clean

